@@ -197,7 +197,6 @@ int			xmlIsChar	(int c);
 /**
  * Parser context
  */
-xmlParserCtxtPtr	xmlCreateDocParserCtxt	(xmlChar *cur);
 xmlParserCtxtPtr	xmlCreateFileParserCtxt	(const char *filename);
 xmlParserCtxtPtr	xmlCreateMemoryParserCtxt(const char *buffer,
 						 int size);
@@ -316,25 +315,25 @@ void			xmlParseExternalSubset	(xmlParserCtxtPtr ctxt,
 /**
  * XML_SUBSTITUTE_NONE:
  *
- * If no entities need to be substitued
+ * If no entities need to be substituted
  */
 #define XML_SUBSTITUTE_NONE	0
 /**
  * XML_SUBSTITUTE_REF:
  *
- * Whether general entities need to be substitued
+ * Whether general entities need to be substituted
  */
 #define XML_SUBSTITUTE_REF	1
 /**
  * XML_SUBSTITUTE_PEREF:
  *
- * Whether parameter entities need to be substitued
+ * Whether parameter entities need to be substituted
  */
 #define XML_SUBSTITUTE_PEREF	2
 /**
  * XML_SUBSTITUTE_BOTH:
  *
- * Both general and parameter entities need to be substitued
+ * Both general and parameter entities need to be substituted
  */
 #define XML_SUBSTITUTE_BOTH 	3
 
@@ -365,7 +364,7 @@ int			namePush		(xmlParserCtxtPtr ctxt,
 						 xmlChar *value);
 
 /*
- * other comodities shared between parser.c and parserInternals
+ * other commodities shared between parser.c and parserInternals
  */
 int			xmlSkipBlankChars	(xmlParserCtxtPtr ctxt);
 int			xmlStringCurrentChar	(xmlParserCtxtPtr ctxt,
@@ -395,6 +394,18 @@ void			xmlParserInputShrink	(xmlParserInputPtr in);
 void			htmlInitAutoClose	(void);
 htmlParserCtxtPtr	htmlCreateFileParserCtxt(const char *filename,
 	                                         const char *encoding);
+
+/*
+ * Specific function to keep track of entities references
+ * and used by the XSLT debugger
+ */
+typedef	void	(*xmlEntityReferenceFunc)	(xmlEntityPtr ent,
+						 xmlNodePtr firstNode,
+						 xmlNodePtr lastNode);
+  
+void		xmlSetEntityReferenceFunc	(xmlEntityReferenceFunc func);
+
+
 #endif
 #ifdef __cplusplus
 }
