@@ -110,7 +110,7 @@ typedef enum {
     XML_ERR_EQUAL_REQUIRED,
 
     XML_ERR_TAG_NAME_MISMATCH, /* 77 */
-    XML_ERR_TAG_NOT_FINISED,
+    XML_ERR_TAG_NOT_FINISHED,
 
     XML_ERR_STANDALONE_VALUE, /* 79 */
 
