@@ -27,21 +27,21 @@ extern void xmlCheckVersion(int version);
  *
  * the version string like "1.2.3"
  */
-#define LIBXML_DOTTED_VERSION "2.4.12"
+#define LIBXML_DOTTED_VERSION "2.4.13"
 
 /**
  * LIBXML_VERSION:
  *
  * the version number: 1.2.3 value is 1002003
  */
-#define LIBXML_VERSION 20412
+#define LIBXML_VERSION 20413
 
 /**
  * LIBXML_VERSION_STRING:
  *
  * the version number string, 1.2.3 value is "1002003"
  */
-#define LIBXML_VERSION_STRING "20412"
+#define LIBXML_VERSION_STRING "20413"
 
 /**
  * LIBXML_TEST_VERSION:
@@ -49,7 +49,7 @@ extern void xmlCheckVersion(int version);
  * Macro to check that the libxml version in use is compatible with
  * the version the software has been compiled against
  */
-#define LIBXML_TEST_VERSION xmlCheckVersion(20412);
+#define LIBXML_TEST_VERSION xmlCheckVersion(20413);
 
 #if 0
 /**
@@ -67,6 +67,15 @@ extern void xmlCheckVersion(int version);
 #define WITHOUT_TRIO
 #endif
 
+/**
+ * LIBXML_THREADS_ENABLED:
+ *
+ * Whether the thread support is configured in
+ */
+#if 0
+#define LIBXML_THREAD_ENABLED
+#endif
+
 /**
  * LIBXML_FTP_ENABLED:
  *
