@@ -11,6 +11,8 @@
 
 #if defined(WIN32) && !defined(__CYGWIN__)
 #include "win32config.h"
+#elif defined(macintosh)
+#include "config-mac.h"
 #else
 #include "config.h"
 #include <libxml/xmlversion.h>
@@ -28,5 +30,6 @@
 #define TRIO_REPLACE_STDIO
 #include "trio.h"
 #endif
+#define IN_LIBXML
 
 #endif /* ! __XML_LIBXML_H__ */
